# Immersive Simulations for Jupyter Notebooks
Enables seamless, minimalistic variable and namespace storage:
  - Shelve storage for per-variable storage and retrieval
  - Quick-Save and Quick-Load of notebook namespace
  - Enable checkpoints so that cells store their starting and ending states

Useful for post-simulation analysis, or ensuring that data
which hasn't been explicitly saved remains entirely available.